@@ -177,7 +177,10 @@ def create_label(
         border_width = 0,
         border_color = "#ffffff",
         border_radius = 0,
-        hover_background_color = "#1e1e1e"
+        hover_background_color = "#1e1e1e",
+        pressed_background_color = "#1e1e1e",
+        disabled_font_color = "#888888",
+        disabled_background_color = "#2d2d2d"
 ):
     label = QLabel(text)
     padding_left_value = padding_left if padding_left is not None else padding
@@ -201,6 +204,13 @@ def create_label(
         QLabel:hover{{
             background-color: {hover_background_color};
         }}
+        QLabel:pressed{{
+            background-color: {pressed_background_color};
+        }}
+        QLabel:disabled{{
+            color: {disabled_font_color};
+            background-color: {disabled_background_color};
+        }}
     """
     label.setStyleSheet(style)
     return label
@@ -234,14 +244,25 @@ def create_button(
     button = QPushButton()
     button.setMaximumWidth(360)
     main_layout = QVBoxLayout(button)
-    label = create_label(text = text, font_size = 16, font_weight = "bold", padding = 5, hover_background_color = "#333333")
+    label = create_label(
+        text = text,
+        font_size = font_size,
+        font_color = font_color,
+        font_weight = "bold",
+        background_color = background_color,
+        padding = padding,
+        padding_left = padding_left,
+        padding_top = padding_top,
+        padding_right = padding_right,
+        padding_bottom = padding_bottom,
+        hover_background_color = hover_background_color,
+        pressed_background_color = pressed_background_color,
+        disabled_font_color = disabled_font_color,
+        disabled_background_color = disabled_background_color
+    )
     label.setAlignment(Qt.AlignmentFlag.AlignCenter)
     label.setWordWrap(True)
     main_layout.addWidget(label)
-    padding_left_value = padding_left if padding_left is not None else padding
-    padding_top_value = padding_top if padding_top is not None else padding
-    padding_right_value = padding_right if padding_right is not None else padding
-    padding_bottom_value = padding_bottom if padding_bottom is not None else padding
     style_sheet = f"""
         QPushButton {{
             font-family: {font_family};
@@ -249,10 +270,7 @@ def create_button(
             color: {font_color};
             font-weight: {font_weight};
             background-color: {background_color};
-            padding-left: {padding_left_value}px;
-            padding-top: {padding_top_value}px;
-            padding-right: {padding_right_value}px;
-            padding-bottom: {padding_bottom_value}px;
+            padding: 0px;
             border: {border_width}px solid {border_color};
             border-radius: {border_radius}px;
         }}
